@@ -6,7 +6,7 @@ from utils import utils
 import os
 
 
-__version__ = '0.0.10'
+__version__ = '0.0.11'
 
 
 GITLAB_TOKEN=os.environ.get("GITLAB_TOKEN")
@@ -19,7 +19,7 @@ Press 2 to add a tool from website
 Press 3 to add a tool from website without specific released version'''
 
 
-def add_tool_or_database(gitlab_token, json_file="https://gitlab.com/intelliseq/iseqresources/-/raw/main/json/tools_and_databases.json"):
+def add_tool_or_database(gitlab_token="", json_file="https://gitlab.com/intelliseq/iseqresources/-/raw/main/json/tools_and_databases.json"):
     if not gitlab_token and json_file.startswith("https://"):
         gitlab_token = utils.get_gitlab_token()
     obj = AddTool(json_file, gitlab_token)
