@@ -8,7 +8,7 @@ from iseqresources.add_task_to_jira import AddTaskToJira
 import os
 
 
-__version__ = '0.0.10'
+__version__ = '0.0.11'
 
 
 GITHUB_TOKEN=os.environ.get("GITHUB_TOKEN")
@@ -17,11 +17,13 @@ JIRA_EMAIL=os.environ.get("JIRA_EMAIL")
 JIRA_TOKEN=os.environ.get("JIRA_TOKEN")
 
 
-def check_for_new_version(github_token, gitlab_token, jira_email, jira_token,
+def check_for_new_version(github_token, jira_email, jira_token, gitlab_token="", 
                         json_file="https://gitlab.com/intelliseq/iseqresources/-/raw/main/json/tools_and_databases.json", 
                         info_json="https://gitlab.com/intelliseq/iseqresources/-/raw/main/json/info.json"):
-    resources_dict = utils.load_json(json_file)
-    jira_project_info = utils.load_json(info_json)
+    if not gitlab_token and json_file.startswith("https://"):
+        gitlab_token = utils.get_gitlab_token()
+    resources_dict = utils.load_json(json_file, gitlab_token)
+    jira_project_info = utils.load_json(info_json, gitlab_token)
     if not github_token:
         github_token = utils.get_github_token()
     if not jira_email:
@@ -39,8 +41,6 @@ def check_for_new_version(github_token, gitlab_token, jira_email, jira_token,
             jira = AddTaskToJira(tool_or_database, jira_email, jira_token, jira_project_info=jira_project_info)
             jira.add_task_to_jira()
     if json_file.startswith("https://"):
-        if not gitlab_token:
-            gitlab_token = utils.get_gitlab_token()
         utils.save_json_to_gitlab(resources_dict, gitlab_token)
     else:
         utils.save_json(json_file, resources_dict)
